@@ -6,7 +6,8 @@ client = TestClient(app)
 def test_root():
     r = client.get("/")
     assert r.status_code == 200
-    assert r.json()["message"].startswith("Hello")
+    # Root now returns HTML page; check for title marker
+    assert b"Folder Vision" in r.content
 
 def test_health():
     r = client.get("/health")
